@@ -1,4 +1,4 @@
-from dataclasses import dataclass, asdict
+from dataclasses import asdict, dataclass
 from pathlib import Path
 from typing import List
 
@@ -12,6 +12,7 @@ class InvalidConfigException(Exception):
 @dataclass
 class MutableConfig:
     exclude: List[str] = None
+    application_import_names: List[str] = None
 
     def dict(self):
         return asdict(self)
@@ -23,16 +24,16 @@ class Config(MutableConfig):
 
 
 def load_config() -> Config:
-    config_path = Path.cwd() / "pyproject.toml"
+    config_path = Path.cwd() / 'pyproject.toml'
     if not config_path.exists():
         return Config()
 
-    project_config = toml.load(config_path)
-    tool_config = project_config.get("tool", {}).get("vgs-style", {})
-    exclude = tool_config.get("exclude")
-    if exclude:
-        tool_config["exclude"] = exclude.split(",")
+    try:
+        project_config = toml.load(config_path)
+    except Exception as exc:
+        raise InvalidConfigException(f'Invalid config: {exc}') from exc
 
+    tool_config = project_config.get('tool', {}).get('vgs-style', {})
     try:
         user_config = MutableConfig(**tool_config)
     except TypeError as exc:
