@@ -38,6 +38,8 @@ class Flake8Linter(Linter):
             str(config.line_length),
             '--import-order-style',
             'pep8',
+            '--ignore',
+            'E203',
         ]
         if config.exclude:
             args.extend(['--extend-exclude', config.exclude])
@@ -69,7 +71,8 @@ class Flake8Linter(Linter):
         with open(dst / '.flake8', 'w') as out:
             out.write('[flake8]\n')
             out.write(f'max-line-length = {self.app.options.max_line_length}\n')
-            out.write(f'import-order-style = pep8\n')
+            out.write(f'import-order-style = {self.app.options.import_order_style}\n')
+            out.write(f'ignore = {",".join(self.app.options.ignore)}\n')
             if self.app.options.extend_exclude:
                 out.write(
                     f'extra-exclude = {",".join(self.app.options.extend_exclude)}\n'
